/////////////////////////////////////////////////////////////////////////////
//
// Undelete
//
// Copyright (C) 1998 Mark Russinovich and Bryce Cogswell
// Systems Internals - http://www.sysinternals.com
//
// See readme.txt for terms of use.
//
/////////////////////////////////////////////////////////////////////////////

// Prop.cpp : implementation file
//

#include "stdafx.h"
#include "afxmt.h"
#include "Undelete.h"
#include "Binheader.h"
#include "Prop.h"
#include "DriveProp.h"
#include "PropSh.h"
#include "UndelDoc.h"
#include "Listvwex.h"
#include "UndelVw.h"


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CProp property page

IMPLEMENT_DYNCREATE(CProp, CPropertyPage)

CProp::CProp() : CPropertyPage(CProp::IDD)
{
	//{{AFX_DATA_INIT(CProp)
	m_ConfigureGlobal = -1;
	m_immediatedelete = FALSE;
	m_PromptOnAction = FALSE;
	m_ExpPrompt = FALSE;
	//}}AFX_DATA_INIT
}

CProp::~CProp()
{
}

void CProp::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CProp)
	DDX_Control(pDX, ID_PERCENT, m_percentrecycle);
	DDX_Radio(pDX, ID_CONFIGEACH, m_ConfigureGlobal);
	DDX_Check(pDX, ID_DISABLEGLOBAL, m_immediatedelete);
	DDX_Check(pDX, ID_PROMPT, m_PromptOnAction);
	DDX_Check(pDX, ID_PROMPT2, m_ExpPrompt);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CProp, CPropertyPage)
	//{{AFX_MSG_MAP(CProp)
	ON_BN_CLICKED(ID_CONFIGEACH, OnConfigeach)
	ON_BN_CLICKED(ID_CONFIGGLOBAL, OnConfigglobal)
	ON_BN_CLICKED(ID_PROMPT, OnPrompt)
	ON_BN_CLICKED(ID_DISABLEGLOBAL, OnDisableglobal)
	ON_WM_HSCROLL()
	ON_WM_SHOWWINDOW()
	ON_WM_CREATE()
	ON_WM_CANCELMODE()
	ON_BN_CLICKED(ID_PROMPT2, OnExpPrompt)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CProp message handlers

BOOL CProp::OnApply()
{
	CSliderCtrl *slider = (CSliderCtrl *) this->GetDlgItem(ID_PERCENT);

	m_GlobalSize = slider->GetPos();

	SetModified(FALSE);
	return TRUE;
}


void CProp::OnConfigeach() 
{
	UpdateData();
	this->GetDlgItem(ID_DISABLEGLOBAL)->EnableWindow( FALSE );
	this->GetDlgItem(ID_PERCENT)->EnableWindow( FALSE );	
	this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( FALSE );	
	this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( FALSE );	
	SetModified( TRUE );
}

void CProp::OnPrompt() 
{
	UpdateData();
	SetModified( TRUE );
}


void CProp::OnConfigglobal() 
{
	UpdateData();

	m_ConfigureGlobal = TRUE;
	this->GetDlgItem(ID_DISABLEGLOBAL)->EnableWindow( TRUE );
	if( !m_immediatedelete ) {

		this->GetDlgItem(ID_PERCENT)->EnableWindow( TRUE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( TRUE );	
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( TRUE );	
	}
	SetModified( TRUE );
}

void CProp::OnDisableglobal() 
{
	UpdateData();
	if( m_immediatedelete ) {

		this->GetDlgItem(ID_PERCENT)->EnableWindow( FALSE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( FALSE );	
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( FALSE );	

	} else {

		this->GetDlgItem(ID_PERCENT)->EnableWindow( TRUE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( TRUE );	
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( TRUE );	
	}
	SetModified( TRUE );
}

BOOL CProp::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	CString percentString;

	CSliderCtrl *slider = (CSliderCtrl *) this->GetDlgItem(ID_PERCENT);

	if( !m_ConfigureGlobal ) {

		this->GetDlgItem(ID_DISABLEGLOBAL)->EnableWindow( FALSE );
		this->GetDlgItem(ID_PERCENT)->EnableWindow( FALSE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( FALSE );
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( FALSE );
	}

	if( m_ConfigureGlobal && m_immediatedelete ) {

		this->GetDlgItem(ID_PERCENT)->EnableWindow( FALSE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( FALSE );
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( FALSE );
	}

	slider->SetRange(0, 100, FALSE );
	slider->SetTicFreq( 10 );
	slider->SetPos( m_GlobalSize );
	
	percentString.Format( _T("%d%%"), m_GlobalSize );
	this->GetDlgItem(IDC_PERCENTSTRING)->SetWindowText( percentString );

	if( m_DisableExpPrompt ) {

		this->GetDlgItem(ID_PROMPT2)->EnableWindow( FALSE );
		this->GetDlgItem(ID_PROMPT2)->ShowWindow( SW_HIDE );
	}

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}


void CProp::OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar) 
{
	CString percentString;

	if( nSBCode == TB_THUMBTRACK || nSBCode == TB_ENDTRACK ||
		nSBCode == TB_LINEUP || nSBCode == TB_LINEDOWN) { 
	
		percentString.Format( _T("%d%%"), ((CSliderCtrl *)pScrollBar)->GetPos() );
		this->GetDlgItem(IDC_PERCENTSTRING)->SetWindowText( percentString );
	}
	SetModified( TRUE );
	
	CPropertyPage::OnHScroll(nSBCode, nPos, pScrollBar);
}

void CProp::OnExpPrompt() 
{
	SetModified( TRUE );
	UpdateData();
}
